The following people contributed to the :py:mod:`rowan` package.

Vyas Ramasubramani <vramasub@umich.edu>, University of Michigan - **Lead developer**.

* Initial design.
* Wrote quaternion operations.
* Wrote calculus subpackage.
* Wrote geometry subpackage.
* Wrote interpolate subpackage.
* Wrote mapping subpackage.
* Wrote random subpackage.
* Wrote documentation.

Bradley Dice <bdice@bradleydice.com>, University of Michigan

* Code review.
* JOSS paper review.
